音乐之声 (豆瓣)
Description: 音乐之声电影简介和剧情介绍,音乐之声影评、图片、预告片、影讯、论坛、在线购票
Keywords: 音乐之声,The Sound of Music,音乐之声影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.70豆瓣电影Top250

# 音乐之声 The Sound of Music (1965)

导演: 罗伯特·怀斯
编剧: 乔治·胡达勒克 / 霍华德·林赛 / 拉塞尔·克劳斯 / 恩斯特·莱赫曼 / 玛丽亚·冯·特拉普
主演: 朱莉·安德鲁斯 / 克里斯托弗·普卢默 / 埃琳诺·帕克 / 理查德·海顿 / 佩吉·伍德 / 查尔敏·卡尔 / 希瑟·孟席斯-尤里克 / 尼古拉斯·哈蒙德 / 杜安·蔡斯 / 安吉拉·卡特怀特 / 黛比·特纳 / 基姆·卡拉思 / 安娜·李 / 波希娅·纳尔逊 / 本·怀特 / 丹尼尔·特鲁希特 / 诺玛·威登 / 吉尔克里斯特·斯图尔特 / 马妮·尼克松 / 埃瓦德妮·贝克 / 多丽丝·劳埃德 / 格特鲁德·阿斯特 / 弗兰克·贝克 / 史蒂夫·卡鲁瑟斯 / 山姆·哈里斯 / 多罗西·吉金斯 / 利奥达·理查德斯 / 杰弗里·塞尔 / 伯纳德·赛尔 / 诺尔曼·斯蒂凡斯 / 伯特史蒂文斯 / 玛丽亚·冯·特拉普
类型: 剧情 / 爱情 / 歌舞 / 传记
制片国家/地区: 美国
语言: 英语 / 德语
上映日期: 1965-03-02(美国)
片长: 174分钟
又名: 仙乐飘飘处处闻(港) / 真善美(台) / 一个叛逆修女的故事
IMDb: tt0059742
豆瓣评分
引用
9.1
570359人评价
5星
61.7%
4星
31.6%
3星
6.3%
2星
0.3%
1星
0.1%
好于 99% 歌舞片
好于 99% 爱情片
想看 看过
评价:
推荐

## 音乐之声的剧情简介 · · · · · ·

玛利亚（朱丽·安德鲁斯 饰）是一个年轻活泼的修女，喜欢在大自然下高声歌唱，所以她常常忘记了修道院里的规矩。院长认为玛利亚并不属于规矩严格的修道院。院长与众嬷嬷商量后，决定安排玛利亚到一位名叫特拉普（克里斯托弗·普卢默 饰）上校家当家庭教师。
上校的妻子去世多年，留下7个孩子，他要求对孩子严格管教。他告诉玛利亚在他家的家庭教师都做不长久，都是因为孩子的恶作剧。玛利亚果然也遭到了恶作剧，可是这位善良的老师并没有告诉他们的父亲，而是像个母亲一样照顾孩子，很快跟孩子打成一片。上校也渐渐在玛利亚的引导下改变了对孩子们的态度。上校与玛利亚之间发生了感情，他们完婚后回到了已被纳粹占领的奥地利，上校并不想为纳粹办事，一家人准备逃跑…… ©豆瓣

## 音乐之声的演职员 · · · · · · ( 全部 41 )

- 罗伯特·怀斯 导演
- 朱莉·安德鲁斯 饰 Maria
- 克里斯托弗·普卢默 饰 Captain Von Trapp
- 埃琳诺·帕克 饰 The Baroness
- 理查德·海顿 饰 Max Detweiler
- 佩吉·伍德 饰 Mother Abbess

## 音乐之声的视频和图片 · · · · · · ( 预告片2 | 添加视频评论 | 图片725 · 添加 )

## 音乐之声的获奖情况 · · · · · · ( 全部 )

- 第38届奥斯卡金像奖
- 最佳影片
- 罗伯特·怀斯

- 第38届奥斯卡金像奖
- 最佳导演
- 罗伯特·怀斯

- 第38届奥斯卡金像奖
- 最佳女主角(提名)
- 朱莉·安德鲁斯

## 喜欢这部电影的人也喜欢 · · · · · ·

  罗马假日

  海上钢琴师

  雨中曲

  爱乐之城

  魂断蓝桥

  泰坦尼克号

  爱在黎明破晓前

  恋恋笔记本

  乱世佳人

  傲慢与偏见

我要写短评

## 音乐之声的短评 · · · · · · ( 全部 80380 条 )

热门 / 最新 / 好友

### 1320 有用 张天师 看过 2006-11-06 10:42:26

真希望世界像它描述的那么美好

### 619 有用 2013 看过 2006-09-11 17:38:57

原谅我，我真的不知道它好看在哪里。

### 1151 有用 薇羅尼卡 看过 2006-02-03 22:37:43

很棒的电影，唱段经久不息，流传至今。

### 1060 有用 superfei 看过 2006-06-05 19:39:14

从小看到现在，大概有50遍了吧。

### 1090 有用 战国客 看过 2009-03-13 23:21:57

难以被超越的音乐剧经典~~

> 更多短评 80380条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 音乐之声的影评 · · · · · · ( 全部 654 条 )

热门 / 最新 / 好友
polymercat 2008-01-12 15:51:20

## 冯.特拉普上校

这篇影评可能有剧透

再次重温了一遍《音乐之声》，再次被感动得几处落泪。在我看来，这部影片堪称经典中的经典。迄今为止在我看过的影片中，论喜爱程度它或许排不到第一，但论最佳影片的话，它却是当之无愧的第一。片中的音乐已是无可争议的经典，《哆唻咪》《孤独的牧羊人》《雪绒花》《音乐之声... (展开)
1054 22 109回应 收起
mubai 2006-04-02 17:32:22

## 看了无数遍了,哈哈

央视音乐《经典》最近正在回顾《音乐之声》，昨天偶然调到，看了一会儿便忍不住又把蝶拿来重新温顾一遍。对于我这种喜欢炒冷饭的习惯很多朋友认为属于闲着没事做，嗯，确实有道理。 　　《音乐之声》，看过无数遍了，不晓得等我老了，它会不会成为我这一辈子看得最多次数的电影... (展开)
192 13 43回应 收起
zeze 2005-11-08 06:54:19

## 二战背景影片之最爱

这篇影评可能有剧透

说起最好看的以二战为背景的电影，很多人会提起辛德勒名单，珍珠港，这里有一个612 Movie Titles (& WWII Links) 1940 - 2000 http://users.aol.com/sailgower/WWIImovies.html .但是我最爱的，却是最容易被遗忘，也最难被遗忘的一部。 Sound of Music. 说它容易被遗忘，... (展开)
112 9 17回应 收起
Autumn 2014-10-08 13:51:54

## 电影中的配角小评

这篇影评可能有剧透

今天重看《音乐之声》，关于配角有了以前没有或者不一样的想法： 关于伯爵夫人的人物塑造，小时候对她的印象就只有坏女人，最多也就是长得漂亮的坏女人。在少时的我看来，一切横隔在男女主之间的女性角色总是不讨喜的。但今天重温时看到她和Captain在阳台告别的那场戏后反有些... (展开)
74 10回应 收起
imrdai 2015-07-31 02:34:51

## 祥和下的残酷

这篇影评可能有剧透

我想大家都对这部影片理解错了，或者大部分人都理解错了。大家说的都是这部电影即使是在二战的背景下的电影，既不血腥，又不残酷，没有杀戮，大家都在唱歌如此的安静祥和。但，我在想，事实真的是这样吗？这部电影本可以放在任何一个安静平和的历史背景里去描写音乐的伟大，他... (展开)
62 3 5回应 收起
不要不开心哦 2017-05-09 16:16:11

## 歌声里的少年时代

这篇影评可能有剧透

《音乐之声》，一部荣获1965年奥斯卡最佳影片奖、最佳导演奖、最佳剪辑奖、最佳音响奖、最佳配乐奖至今仍被奉为歌舞类电影的神作，音乐不仅刻画人物性格、烘托场景气氛，还对推进剧情起到重要作用。身处动荡政局的一家人，以歌曲消除隔膜，维系爱国情怀，更以音乐演出的形式巧... (展开)
36 3 3回应 收起
爱吃馒头的宝宝 2017-09-01 23:03:02

## 声与影绝佳的契合

这篇影评可能有剧透

声与影绝佳的契合，放才能诞生如《音乐之声》这光影的典藏，电影不仅关乎情感更关乎于战争，但其所呈现的一切却又是那般美好，七个孩子天籁般的童声沁人心脾，用音乐所洋溢的情感充沛而真挚，美景美声美乐编织了一个梦幻的至美之境。 很让人放松，音乐实在经典。片长三小时而全... (展开)
43 0回应 收起
开心快乐每一天 2017-04-26 12:26:51

## 音乐是最美好的

我家有很多VCD，最喜欢的，让我每过一段时间就会想看一遍的一定是《音乐之声》。玛丽亚活泼开朗、俏皮甜美，每次她出场我会情不自禁跟着笑，电影的情节几乎背的下来，歌都会唱。被松果扎到屁股叫着跳起来的样子，雨夜和孩子们扔枕头狂闹的样子（我一直很羡慕可以这样闹），和上... (展开)
43 0回应 收起
BBS 2008-07-29 13:09:51

## 音乐渗浸人生

我们常常会因为一首歌曲、一段音乐的精彩而感受出一部电影的经典。多年以后，也许我们对那些电影的情节、内容已不再持有清晰的记忆，但想起它们中一些出色的乐曲，总能使人产生往复的回味。 近似或完全等同于许多人的感受，电影《音乐之声》最令我观时兴奋和过后难忘的，正是其... (展开)
71 2 8回应 收起

> 更多影评 654篇

添加新讨论

## 讨论区 · · · · · ·

我来告诉大家一个秘密～～ | 来自萨尔斯堡的女招待 | 42 回应 | 2022-11-17 18:58:15
Captain为何不让孩子公开演出呢，孩子们的家庭曲目... | 来自向阳 |  | 2022-11-03 08:35:55
看完临睡觉前满脑子里还都是孤独的牧羊人的调调 | 来自cy |  | 2022-10-13 00:38:49
我很喜欢 | 来自..愫 |  | 2022-09-21 07:10:57
音乐之声 | 来自笨笨 |  | 2022-09-18 07:02:52

> 去这部影片的讨论区（全部152条）

## 关于《音乐之声》的问题 · · · · · · ( 全部7个 )

- Uncle Max和Baroness是什么关系？ 6人回答
- 影片里面的歌舞是由演员本人亲自演唱吗？ 3人回答

> 全部7个问题

## 在哪儿看这部电影 · · · · · ·

- 咪咕视频 VIP免费观看
- 爱奇艺视频 VIP免费观看
- 腾讯视频 VIP免费观看
- 哔哩哔哩 免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【内牛满面】 (影志)
- 【励志电影】 (影志)
- 【城市印象】— 跟着电影去旅行 (狷介有乌青)
- 入选《第十放映室》影片之国外篇Ⅰ (心之旋影)

## 谁在看这部电影 · · · · · ·

- 再见白丝
  3分钟前 想看
- 李和田田
  3分钟前 看过
- 杨坚强
  5分钟前 看过

966969人看过 / 169630人想看

订阅音乐之声的评论:
feed: rss 2.0